@@ -75,7 +75,7 @@ extern void GPUreadDataMem(uint32_t *, int);
 extern long GPUdmaChain(uint32_t *,uint32_t);
 extern void GPUupdateLace(void);
 extern long GPUfreeze(uint32_t, void *);
-extern void GPUvBlank(int, uint32_t *, uint32_t *);
+extern void GPUvBlank(int, int);
 extern void GPUrearmedCallbacks(const struct rearmed_cbs *cbs);
 
 
@@ -168,7 +168,7 @@ static const struct {
 	DIRECT_GPU(GPUwriteDataMem),
 	DIRECT_GPU(GPUdmaChain),
 	DIRECT_GPU(GPUfreeze),
-//	DIRECT_GPU(GPUvBlank), // unused
+	DIRECT_GPU(GPUvBlank),
 	DIRECT_GPU(GPUrearmedCallbacks),
 
 	DUMMY_GPU(GPUdisplayText),
