@@ -72,7 +72,7 @@ struct rearmed_cbs {
 		int   dwActFixes;
 		int   bDrawDither, iFilterType, iFrameTexType;
 		int   iUseMask, bOpaquePass, bAdvancedBlend, bUseFastMdec;
-		int   iVRamSize, iTexGarbageCollection;
+		int   iVRamSize, iTexGarbageCollection, bKeepRatio;
 	} gpu_peopsgl;
 };
 
