@@ -584,6 +584,23 @@ inline void key_press_event(int key2,int type)
 				in_keystate |= 1 << psxkey1;
 			if (psxkey2 >= 0)
 				in_keystate |= 1 << psxkey2;
+
+			if (in_type1 == PSE_PAD_TYPE_ANALOGPAD){
+				switch(psxkey1){
+					case DKEY_LEFT:
+						in_a1[0] = 0;
+						break;
+					case DKEY_RIGHT:
+						in_a1[0] = 255;
+						break;
+					case DKEY_UP:
+						in_a1[1] = 0;
+						break;
+					case DKEY_DOWN:
+						in_a1[1] = 255;
+						break;
+				}
+			}
 		}
 		else if (type == 2) {
 			if (psxkey1 >= 0)
@@ -591,6 +608,18 @@ inline void key_press_event(int key2,int type)
 			if (psxkey2 >= 0)
 				in_keystate &= ~(1 << psxkey2);
 
+			if (in_type1 == PSE_PAD_TYPE_ANALOGPAD){
+				switch(psxkey1){
+					case DKEY_LEFT:
+					case DKEY_RIGHT:
+						in_a1[0] = 127;
+						break;
+					case DKEY_UP:
+					case DKEY_DOWN:
+						in_a1[1] = 127;
+						break;
+				}
+			}
 			emu_set_action(SACTION_NONE);
 		}
 	}
