@@ -48,11 +48,9 @@ static void DestroyKeyboard(void) {
 
 int maemo_x11_update_keys() {
 
-	//uint8_t					i;
 	XEvent					evt;
 	XClientMessageEvent		*xce;
-	//uint16_t				Key;
-	int /*psxkey,*/ leave = 0;
+	int leave = 0;
 	Display *disp = (Display *)gpuDisp;
 	
 	if (!disp)
