@@ -117,6 +117,13 @@ void PrintHelp()
     printf("                   3=Change slot (+1)\n");
     printf("                   4=Change slot (-1)\n");
     printf("                   5=Quit\n");
+	printf("  -guncon        : Set the controller to guncon\n");
+	printf("  -gunnotrigger  : Don't trigger (shoot) when touching screen\n");
+	printf("  -cdsched VALUE : CD read reschedule hack\n");
+    printf("                   0=Auto (Default)\n");
+    printf("                   1=On\n");
+    printf("                   2=Off\n");
+
 
 	printf("\nGPU Options:\n");
 	printf("  -gles          : Use the GLES plugin (gpuGLES.so)\n");
@@ -191,6 +198,7 @@ int maemo_main(int argc, char **argv)
 	strcpy(Config.PluginsDir, "/opt/maemo/usr/games/plugins");
 	snprintf(Config.PatchesDir, sizeof(Config.PatchesDir), "/opt/maemo/usr/games" PATCHES_DIR);
 	Config.PsxAuto = 1;
+	Config.CdrReschedule = 0;
 	pl_rearmed_cbs.frameskip = -1;
 	strcpy(Config.Bios, "HLE");
     iUseReverb = 0;
@@ -263,7 +271,10 @@ int maemo_main(int argc, char **argv)
 		else if (!strcmp(argv[i], "-mcd1")) 	            sprintf(Config.Mcd1, "%s", argv[++i]);
 		else if (!strcmp(argv[i], "-mcd2")) 	            sprintf(Config.Mcd2, "%s", argv[++i]);
 
+		else if (!strcmp(argv[i], "-cdsched")) 				Config.CdrReschedule = atol(argv[++i]);
 		else if (!strcmp(argv[i], "-cpuclock")) 	        cycle_multiplier = 10000 / atol(argv[++i]);
+		else if (!strcmp(argv[i], "-guncon")) 	            in_type1 = PSE_PAD_TYPE_GUNCON;
+		else if (!strcmp(argv[i], "-gunnotrigger")) 		g_opts |= OPT_TSGUN_NOTRIGGER;
 		else if (!strcmp(argv[i], "-analog")) 	            in_type1 = PSE_PAD_TYPE_ANALOGPAD;
 		else if (!strcmp(argv[i], "-vibration")) 	        { in_type1 = PSE_PAD_TYPE_ANALOGPAD; in_enable_vibration = 1; }
 		else if (!strcmp(argv[i], "-sens")) 				accelOptions.sens = atol(argv[++i]);
@@ -304,8 +315,7 @@ int maemo_main(int argc, char **argv)
 		}
 	}
 
-	in_enable_vibration = 1;
-	hildon_init(&argc, &argv);
+	//hildon_init(&argc, &argv);
 
 	if (cdfile) {
 		set_cd_image(cdfile);
